@@ -146,8 +146,8 @@ class KNNMemory():
     
     def set_scoped_indices(self, indices):
         indices = list(indices)
-        assert all_el_unique(indices), 'all scoped batch indices must be unique'
-        assert all([0 <= i < self.num_indices for i in indices]), f'each batch index must be between 0 and less than {self.num_indices}'
+        assert all_el_unique(indices), f'all scoped batch indices must be unique, received: {indices}'
+        assert all([0 <= i < self.num_indices for i in indices]), f'each batch index must be between 0 and less than {self.num_indices}: received {indices}'
         self.scoped_indices = indices
 
     @contextmanager
